[coreboot] [commit] r5582 - trunk/src/devices/oprom

repository service svn at coreboot.org
Sun May 23 13:08:38 CEST 2010


Author: stepan
Date: Sun May 23 13:08:37 2010
New Revision: 5582
URL: https://tracker.coreboot.org/trac/coreboot/changeset/5582

Log:
consistently use decimal for the register offsets, and fix comment typos.

Signed-off-by: Stefan Reinauer <stepan at coresystems.de>
Acked-by: Stefan Reinauer <stepan at coresystems.de>

Modified:
   trunk/src/devices/oprom/x86_asm.S

Modified: trunk/src/devices/oprom/x86_asm.S
==============================================================================
--- trunk/src/devices/oprom/x86_asm.S	Sun May 23 06:50:41 2010	(r5581)
+++ trunk/src/devices/oprom/x86_asm.S	Sun May 23 13:08:37 2010	(r5582)
@@ -59,12 +59,12 @@
 
 /* Register store for realmode_call and realmode_interrupt */
 __registers = RELOCATED(.)
-	.long 0 /* 0x00 - EAX */
-	.long 0 /* 0x04 - EBX */
-	.long 0 /* 0x08 - ECX */
-	.long 0 /* 0x0c - EDX */
-	.long 0 /* 0x10 - EDI */
-	.long 0 /* 0x14 - ESI */
+	.long 0 /*  0 - EAX */
+	.long 0 /*  4 - EBX */
+	.long 0 /*  8 - ECX */
+	.long 0 /* 12 - EDX */
+	.long 0 /* 16 - ESI */
+	.long 0 /* 20 - EDI */
 
 	.code32
 	.globl __realmode_call
@@ -89,17 +89,17 @@
 
 	/* initial register values */
 	movl	40(%ebp), %eax
-	movl	%eax, __registers + 0x00 /* eax */
+	movl	%eax, __registers +  0 /* eax */
 	movl	44(%ebp), %eax
-	movl	%eax, __registers + 0x04 /* ebx */
+	movl	%eax, __registers +  4 /* ebx */
 	movl	48(%ebp), %eax
-	movl	%eax, __registers + 0x08 /* ecx */
+	movl	%eax, __registers +  8 /* ecx */
 	movl	52(%ebp), %eax
-	movl	%eax, __registers + 0x0c /* edx */
+	movl	%eax, __registers + 12 /* edx */
 	movl	56(%ebp), %eax
-	movl	%eax, __registers + 0x10 /* esi */
+	movl	%eax, __registers + 16 /* esi */
 	movl	60(%ebp), %eax
-	movl	%eax, __registers + 0x14 /* esi */
+	movl	%eax, __registers + 20 /* edi */
 
 	/* Activate the right segment descriptor real mode. */
 	ljmp	$0x28, $RELOCATED(1f)
@@ -210,17 +210,17 @@
 
 	/* initial register values */
 	movl	40(%ebp), %eax
-	movl	%eax, __registers + 0x00 /* eax */
+	movl	%eax, __registers +  0 /* eax */
 	movl	44(%ebp), %eax
-	movl	%eax, __registers + 0x04 /* ebx */
+	movl	%eax, __registers +  4 /* ebx */
 	movl	48(%ebp), %eax
-	movl	%eax, __registers + 0x08 /* ecx */
+	movl	%eax, __registers +  8 /* ecx */
 	movl	52(%ebp), %eax
-	movl	%eax, __registers + 0x0c /* edx */
+	movl	%eax, __registers + 12 /* edx */
 	movl	56(%ebp), %eax
-	movl	%eax, __registers + 0x10 /* esi */
+	movl	%eax, __registers + 16 /* esi */
 	movl	60(%ebp), %eax
-	movl	%eax, __registers + 0x14 /* esi */
+	movl	%eax, __registers + 20 /* edi */
 
 	/*  This configures CS properly for real mode. */
 	ljmp 	$0x28, $RELOCATED(1f)




More information about the coreboot mailing list